@@ -3,7 +3,7 @@ package Sah::Schema::country::code;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Country'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use Locale::Codes::Country_Codes ();
 
@@ -28,8 +28,8 @@ _
     'x.perl.coerce_rules' => ['From_str::to_lower'],
     examples => [
         {value=>'', valid=>0},
-        {value=>'ID' , valid=>1, res=>'id'},
-        {value=>'IDN', valid=>1, res=>'idn'},
+        {value=>'ID' , valid=>1, validated_value=>'id'},
+        {value=>'IDN', valid=>1, validated_value=>'idn'},
         {value=>'xx', valid=>0},
         {value=>'xxx', valid=>0},
     ],
@@ -50,7 +50,7 @@ Sah::Schema::country::code - Country code (alpha-2 or alpha-3)
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::country::code (from Perl distribution Sah-Schemas-Country), released on 2020-03-04.
+This document describes version 0.007 of Sah::Schema::country::code (from Perl distribution Sah-Schemas-Country), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -88,9 +88,9 @@ Sample data:
 
  undef  # INVALID
 
- undef  # valid, becomes "id"
+ undef  # valid
 
- undef  # valid, becomes "idn"
+ undef  # valid
 
  undef  # INVALID
 
