@@ -3,7 +3,7 @@ package Sah::Schema::country::code::alpha2;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Country'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use Locale::Codes::Country_Codes ();
 
@@ -27,7 +27,7 @@ _
     'x.perl.coerce_rules' => ['From_str::to_lower'],
     examples => [
         {value=>'', valid=>0},
-        {value=>'ID' , valid=>1, res=>'id'},
+        {value=>'ID' , valid=>1, validated_value=>'id'},
         {value=>'IDN', valid=>0, summary=>'Only alpha-2 codes are allowed'},
         {value=>'xx', valid=>0},
         {value=>'xxx', valid=>0},
@@ -49,7 +49,7 @@ Sah::Schema::country::code::alpha2 - Country code (alpha-2)
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::country::code::alpha2 (from Perl distribution Sah-Schemas-Country), released on 2020-03-04.
+This document describes version 0.007 of Sah::Schema::country::code::alpha2 (from Perl distribution Sah-Schemas-Country), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -87,7 +87,7 @@ Sample data:
 
  undef  # INVALID
 
- undef  # valid, becomes "id"
+ undef  # valid
 
  undef  # INVALID (Only alpha-2 codes are allowed)
 
