@@ -3,7 +3,7 @@ package Sah::Schema::country::code::alpha3;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Country'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use Locale::Codes::Country_Codes ();
 
@@ -28,7 +28,7 @@ _
     examples => [
         {value=>'', valid=>0},
         {value=>'ID' , valid=>0, summary=>'Only alpha-3 codes are allowed'},
-        {value=>'IDN', valid=>1, res=>'idn'},
+        {value=>'IDN', valid=>1, validated_value=>'idn'},
         {value=>'xx', valid=>0},
         {value=>'xxx', valid=>0},
     ],
@@ -49,7 +49,7 @@ Sah::Schema::country::code::alpha3 - Country code (alpha-3)
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::country::code::alpha3 (from Perl distribution Sah-Schemas-Country), released on 2020-03-04.
+This document describes version 0.007 of Sah::Schema::country::code::alpha3 (from Perl distribution Sah-Schemas-Country), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -89,7 +89,7 @@ Sample data:
 
  undef  # INVALID (Only alpha-3 codes are allowed)
 
- undef  # valid, becomes "idn"
+ undef  # valid
 
  undef  # INVALID
 
